@@ -9,10 +9,7 @@ class Command:
         self.loop = asyncio.get_event_loop()
 
     async def prepare(self):
-        from jija.apps import Apps
         from jija.database.config import DatabaseConfig
-
-        Apps.load()
         DatabaseConfig.load()
 
         await Tortoise.init(config=DatabaseConfig.get_config())
